% ---------------------------------------------------------------
% B=FourierBasis(b,n)
%
% Returns the base matrix to get the Fourier coeficients of an image.
% This base matrix can be later used in the project/reconstruct functions.
%
% The notation 'b' and 'n' corresponds to the one used in the Project
% function. 'b' are the columns/rows of the input image and 'n' are the
% rows/columns of the coefficicient matrix.
%
% Input parameters:
%       > b: rows of B (number of elements per vector)
%       > n: columns of B (number of vectors in the base)
% Output parameters:
%       > B: The base matrix
%
% ---------------------------------------------------------------
function B=FourierBasis(b,n)
  B=zeros(b,n);
  r=(n-1)/2;
  for l=1:n
    r2=(l-r-1);
    for k=1:b
      z=-j*2*pi*((k-1)*r2)/b;
      B(k,l)=exp(z);
    end
  end
  B=(1/sqrt(b))*B; 
