% ---------------------------------------------------------------
% B=MomentsBasis(b,n)
%
% Returns the base matrix corresponding to the moments of an image.
% This base matrix can be later used in the project/reconstruct functions.
%
% The notation 'b' and 'n' corresponds to the one used in the Project
% function. 'b' are the columns/rows of the input image and 'n' are the
% rows/columns of the coefficicient matrix.
%
% Input parameters:
%       > b: rows of B (number of elements per vector)
%       > n: columns of B (number of vectors in the base)
% Output parameters:
%       > B: The base matrix
%
% ---------------------------------------------------------------
function B=MomentsBasis(b,n)

  B=zeros(b,n);
  for k=1:b
    for l=1:n
      B(k,l)=k^(l-1);
    end
  end


