% ---------------------------------------------------------------
% I=Reconstruct(B1,P,B2)
%
% Reconstructs and image I from its projection matrix P using the basis matrix B1
% and B2 obtained from the same function (but with different parameters/sizes).
% ATTENTION: the base 'B1/B2' must be the same used in the projection to obtaion 'P'
%     (see function in Project.m)
%
% The original image is only fully recoverd if we used enough coeficients
% in the projection. If not, we get a least-square approximation.
% This reconstruction formula is the one in lema 1 of section  II of the
% article 'Moment-Preserving Image Approximation'
%
% To recostruct an image with a base different from the projection one
% see Reconstruct2.m. This implements Lema 2 of section II of the paper
% 'Moment-Preserving Image Approximations'
%
% The 'real' is used since Fourier uses complex part that has to be removed.
%
% The size of the matrixes is relevant!!
%
% Input parameters:
%       > B1: Vectors of the matrix base used in the projection/reconstruction
%             Matrix size (a,m)
%       > P: Projection matrix
%            Matrix size (m,n)
%       > B2: Vectors of the base used in the projection/reconstruction
%            Matrix size (b,n)
% Output parameters:
%       > I: The reconstructed image
%            Matrix size (a,b) (the size of the original image)
%
% ---------------------------------------------------------------
function I=Reconstruct(B1,P,B2)
  I=real((B1* InvertMatrix(B1' * B1)) * P * (InvertMatrix(B2' * B2) * B2'));
  %I=real(B1* ((B1' * B1) \ P) * ((B2' * B2) \ B2'));

