% ---------------------------------------------------------------
% I=Reconstruct2(Ba,B1,P,B2,Bb)
%
% Reconstructs and image I in terms of an arbitrary ORTHNORMAL basis Ba, Bb
% from its projection coeficients P obtained using bases B1 and B2.
%
% In other words, the base 'B1/B2' are the ones used to project 'I'
%     (see function in project.m)
% and Ba Bb are the basis we want to use to reconstruct the image.
%
% The reconstruction in using a base different from the one used in
% projection is achieved applying lema 2 of section  II of the
% article 'Moment-Preserving Image Approximation'
%
% After the reconstruction the image is normalize in the range [0.1] so
% it can be properly displayed in grayscale using imshow().
%
% To recostruct an image with a the same base used in the projection
% see Reconstruct.
%
% The size of the matrixes is relevant!!
%
% Input parameters:
%       > Ba: Vector of the base used for reconstruction
%             Matrix size (a,m)
%       > B1: Vectors of the base used in the projection
%             Matrix size (a,m)
%       > P: Projection coeficients
%            Matrix size (m,n)
%       > B2: Vectors of the base used in the projection
%            Matrix size (b,n)
%       > Bb: Vectors of the base used in the reconstruction
%            Matrix size (b,n)
% Output parameters:
%       > I: The reconstructed image
%            Matrix size (a,b) (the size of the original image)
%
% ---------------------------------------------------------------
function I=Reconstruct2(Ba,B1,P,B2,Bb)
  C1=B1'*Ba;
  if (det(C1)==0)
   error('Singular matrix in Reconstruct2');
  end
  C2=Bb'*B2;
  if (det(C2)==0)
   error('Singular matrix in Reconstruct2');
  end
  I=real( Ba * InvertMatrix(C1) * P * InvertMatrix(C2) * Bb');
  %I=real( Ba * (C1 \ P) * (C2 \ Bb'));

