% ---------------------------------------------------------------
% P=ReconstructNaiveF(a,b,P,F)
%
% Reconstruct and image I from its coeficients matrix up
% to order (m,n). The result is a image matrix with size (a,b)
% The coefficient matrix P must the obtained with function F
%
% This is the naif version of the reconstruction of an image.
% The unknow coefficients are taken as zero.
%
% Input parameters:
%       > a: rows for the image matrix
%       > b: columns for the image matrix
%       > P: The projection matrix with the coefficients
%            Matrix size (m,n)
%       > F: The function used to generate the coefficients.
%            Predefined functions are:
%                - MomentsBasis
%                - ChebyshevBasis
%                - FourierBasis
%                - HaarBasis
% Output parameters:
%       > I: Image recovered.
%            Matrix size (a,b)
%
% ---------------------------------------------------------------
function I=ReconstructNaiveF(a,b,P,F)
  [m,n]=size(P);
  if (m>a) | (n>b)
     error('Projection matrix of size (%u %u) larger than image matrix with size (%u %u).',m,n,a,b);
  end

  Baa=feval(F,a,a);
  iBaa=InvertMatrix(Baa);
  if a~=b
    Bbb=feval(F,b,b);
    iBbb=InvertMatrix(Bbb);
  else
    Bbb=Baa;
    iBbb=iBaa;
  end

  % We set the unknown coefficients to 0
  Pab=zeros(a,b);
  Pab(1:m,1:n)=P;

  I=iBaa'* Pab * iBbb;
