% ---------------------------------------------------------------
% P=ReconstructNaiveMoments(a,b,P)
%
% Reconstruct and image I from its coeficients matrix up
% to order (m,n). The result is a image matrix with size (a,b)
% The coefficient matrix P must the obtained with the MomentsBasis
% Projection.
%
% This is the naif version of the reconstruction of an image
% from its moments. The unknown moments are inferred form an
% average image defined form the moment of order (1,1)
%
% See also ReconstructNaiveF for a general Naif reconstruction method
% where the unkown coeficients are defined to 0.
%
% Input parameters:
%       > a: rows for the image matrix
%       > b: columns for the image matrix
%       > P: The projection matrix with the coefficients
%            Matrix size (m,n)
%
% Output parameters:
%       > I: Image recovered.
%            Matrix size (a,b)
%
% ---------------------------------------------------------------
function I=ReconstructNaiveMoments(a,b,P)
  [m,n]=size(P);
  if (m>a) | (n>b)
     error('Projection matrix of size (%u %u) larger than image matrix with size (%u %u).',m,n,a,b);
  end

  Baa=MomentsBasis(a,a);
  iBaa=InvertMatrix(Baa);
  if a~=b
    Bbb=MomentsBasis(b,b);
    iBbb=InvertMatrix(Bbb);
  else
    Bbb=Baa;
    iBbb=iBaa;
  end

  % We set the unknown coefficients to 0
  Pab=Project(Baa,(P(1,1)/(a*b)*ones(a,b)),Bbb);
  Pab(1:m,1:n)=P;

  I=iBaa' * Pab * iBbb;


