% STIRLING1(n,m) returns Stirling Number of the First Kind
%  All inputs and output scalar and n >= m
%  See Abramowitz and Stegun, 24.1.3 I.C
%
%
%  Matlab code by Michael Gordy <michael.gordy.es.85@aya.yale.edu>.
%  Copied from url: http://mgordy.tripod.com/research.html
%
function S=stirling1(n,m)
%  Matlab code by Michael Gordy <michael.gordy.es.85@aya.yale.edu>.

% special cases
if (m==0), S=(n==0); return, end
if (m==1), S=(-1)^(n-1)*gamma(n); return, end
if (m==n), S=1; return, end
if ((m+1)==n), S=-nchoosek(n,2); return, end

% initializations
S=0;
lncc=gammaln(2*n-m+1)-gammaln(m);
lnak=(-2*gammaln(n-m+1));
sgn=1;
for k=0:(n-m)
  % first tally in
  S=S+sgn*exp(lncc+lnak-log(n+k))*stirling2(n-m+k,k);
  % then prepare for next k
  warning off, lnak=lnak+log(n-m-k)-log(n-m+k+1); warning on
  sgn=-1*sgn;
end

function S=stirling2(n,m)
%STIRLING2(n,m) returns Stirling Number of the Second Kind
%  All inputs and output scalar.
%  See Abramowitz and Stegun, 24.1.4 I.C

%  Matlab code by Michael Gordy <michael.gordy.es.85@aya.yale.edu>.

% special cases
if (m==0), S=(n==0); return, end
if (m==1) | (m==n), S=1; return, end
if ((m+1)==n), S=nchoosek(n,2); return, end

kk=(0:m);
c=exp(-gammaln(kk+1)-gammaln(m-kk+1));
sgn=(-1)^mod(m+1,2)*cumprod(repmat(-1,1,m+1));
S=sum(sgn.*c.*(kk.^n));
