% ---------------------------------------------------------------
% V=VandermondeMatrix(b,v)
%
% Returns the (b,n) Vandermonde matrix with bases v_1...v_n.
% The MomentsBasis function is a particular case of this function
% with v_i=i and transposing the result.
%
% The notation 'b' and 'n' corresponds to the one used in the Project
% function. 'b' are the columns/rows of the input image and 'n' are the
% rows/columns of the coefficicient matrix.
%
% Please, see the vander MatLab function for an alternative.
% (the MatLab function returns the matrix with a different row
%  order).
%
% Input parameters:
%       > b: rows and colums of the output V
%       > v: vector of size n with the bases
% Output parameters:
%       > V: The (b,n) Vandermonde matrix
%
% ---------------------------------------------------------------
function V=VandermondeMatrix(b,v)
  if (size(v,1)~=1)
     error('The second parameter of the VandermondeMatrix function must be a vector');
  end
  n=size(v,2);
  V=zeros(b,n);
  for k=1:b
    for l=1:n
      V(k,l)=v(l)^(k-1);
    end
  end

